@@ -1,24 +1,7 @@
-# The MIT License (MIT)
+# SPDX-FileCopyrightText: 2021 Melissa LeBlanc-Williams for Adafruit Industries
 #
-# Copyright (c) 2020 Melissa LeBlanc-Williams for Adafruit Industries
-#
-# Permission is hereby granted, free of charge, to any person obtaining a copy
-# of this software and associated documentation files (the "Software"), to deal
-# in the Software without restriction, including without limitation the rights
-# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
-# copies of the Software, and to permit persons to whom the Software is
-# furnished to do so, subject to the following conditions:
-#
-# The above copyright notice and this permission notice shall be included in
-# all copies or substantial portions of the Software.
-#
-# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
-# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
-# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
-# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
-# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
-# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
-# THE SOFTWARE.
+# SPDX-License-Identifier: MIT
+
 """
 `adafruit_platformdetect.chip`
 ================================================================================
@@ -32,16 +15,22 @@ Implementation Notes
 
 **Software and Dependencies:**
 
-* Linux and Python 3.5 or Higher
+* Linux and Python 3.7 or Higher
 
 """
 
-# imports
+
 import os
 import sys
 
+try:
+    from typing import Optional
+except ImportError:
+    pass
+
 from adafruit_platformdetect.constants import chips
 
+
 __version__ = "0.0.0-auto.0"
 __repo__ = "https://github.com/adafruit/Adafruit_CircuitPython_PlatformDetect.git"
 
@@ -49,14 +38,16 @@ __repo__ = "https://github.com/adafruit/Adafruit_CircuitPython_PlatformDetect.gi
 class Chip:
     """Attempt detection of current chip / CPU."""
 
-    def __init__(self, detector):
+    def __init__(self, detector) -> None:
         self.detector = detector
         self._chip_id = None
 
     @property
     def id(
         self,
-    ):  # pylint: disable=invalid-name,too-many-branches,too-many-return-statements
+    ) -> Optional[
+        str
+    ]:  # pylint: disable=invalid-name,too-many-branches,too-many-return-statements
         """Return a unique id for the detected chip, if any."""
         # There are some times we want to trick the platform detection
         # say if a raspberry pi doesn't have the right ID, or for testing
@@ -113,25 +104,24 @@ class Chip:
 
                 # look for it based on PID/VID
                 for dev in hid.enumerate():
-                    # Raspberry Pi Pico
-                    if dev["vendor_id"] == 0xCAFE and dev["product_id"] == 0x4005:
-                        self._chip_id = chips.PICO_U2IF
-                        return self._chip_id
-                    # Feather RP2040
-                    if dev["vendor_id"] == 0x239A and dev["product_id"] == 0x00F1:
-                        self._chip_id = chips.FEATHER_U2IF
-                        return self._chip_id
-                    # Itsy Bitsy RP2040
-                    if dev["vendor_id"] == 0x239A and dev["product_id"] == 0x00FD:
-                        self._chip_id = chips.ITSYBITSY_U2IF
-                        return self._chip_id
-                    # QT Py RP2040
-                    if dev["vendor_id"] == 0x239A and dev["product_id"] == 0x00F7:
-                        self._chip_id = chips.QTPY_U2IF
-                        return self._chip_id
-                    # QT2040 Trinkey
-                    if dev["vendor_id"] == 0x239A and dev["product_id"] == 0x0109:
-                        self._chip_id = chips.QT2040_TRINKEY_U2IF
+                    vendor = dev["vendor_id"]
+                    product = dev["product_id"]
+                    # NOTE: If any products are added here, they need added
+                    # to _rp2040_u2if_id() in board.py as well.
+                    if (
+                        # Raspberry Pi Pico
+                        vendor == 0xCAFE
+                        and product == 0x4005
+                    ) or (
+                        # Feather RP2040
+                        # Itsy Bitsy RP2040
+                        # QT Py RP2040
+                        # QT2040 Trinkey
+                        # MacroPad RP2040
+                        vendor == 0x239A
+                        and product in (0x00F1, 0x00FD, 0x00F7, 0x0109, 0x0107)
+                    ):
+                        self._chip_id = chips.RP2040_U2IF
                         return self._chip_id
                 raise RuntimeError(
                     "BLINKA_U2IF environment variable "
@@ -172,10 +162,29 @@ class Chip:
 
     # pylint: enable=invalid-name
 
-    def _linux_id(self):
+    def _linux_id(self) -> Optional[str]:
         # pylint: disable=too-many-branches,too-many-statements
         # pylint: disable=too-many-return-statements
         """Attempt to detect the CPU on a computer running the Linux kernel."""
+        if self.detector.check_dt_compatible_value("ti,am654"):
+            return chips.AM65XX
+
+        if self.detector.check_dt_compatible_value("ti,am652"):
+            return chips.AM65XX
+
+        if self.detector.check_dt_compatible_value("sun4i-a10"):
+            return chips.A10
+
+        if self.detector.check_dt_compatible_value("sun7i-a20"):
+            return chips.A20
+
+        if self.detector.check_dt_compatible_value("amlogic,g12a"):
+            return chips.S905Y2
+        if self.detector.check_dt_compatible_value("amlogic, g12a"):
+            return chips.S905X3
+
+        if self.detector.check_dt_compatible_value("sun8i-h3"):
+            return chips.H3
 
         if self.detector.check_dt_compatible_value("qcom,apq8016"):
             return chips.APQ8016
@@ -186,8 +195,13 @@ class Chip:
         if self.detector.check_dt_compatible_value("sun20iw1p1"):
             return chips.C906
 
+        # Older Builds
         if self.detector.check_dt_compatible_value("sifive"):
-            return chips.VICU7
+            return chips.JH71x0
+
+        # Newer Builds
+        if self.detector.check_dt_compatible_value("jh7100"):
+            return chips.JH71x0
 
         if self.detector.check_dt_compatible_value("sun8i-a33"):
             return chips.A33
@@ -195,6 +209,9 @@ class Chip:
         if self.detector.check_dt_compatible_value("rockchip,rk3308"):
             return chips.RK3308
 
+        if self.detector.check_dt_compatible_value("radxa,rock-4c-plus"):
+            return chips.RK3399_T
+
         if self.detector.check_dt_compatible_value("rockchip,rk3399"):
             return chips.RK3399
 
@@ -204,23 +221,41 @@ class Chip:
         if self.detector.check_dt_compatible_value("rockchip,rk3328"):
             return chips.RK3328
 
+        if self.detector.check_dt_compatible_value("rockchip,rk3566"):
+            return chips.RK3566
+
+        if self.detector.check_dt_compatible_value("rockchip,rk3568"):
+            return chips.RK3568
+
+        if self.detector.check_dt_compatible_value("rockchip,rk3568b2"):
+            return chips.RK3568B2
+
+        if self.detector.check_dt_compatible_value("rockchip,rk3588"):
+            return chips.RK3588
+
+        if self.detector.check_dt_compatible_value("amlogic,a311d"):
+            return chips.A311D
+
         if self.detector.check_dt_compatible_value("st,stm32mp157"):
             return chips.STM32MP157
 
+        if self.detector.check_dt_compatible_value("st,stm32mp153"):
+            return chips.STM32MP157DAA1
+
         if self.detector.check_dt_compatible_value("sun50i-a64"):
             return chips.A64
 
         if self.detector.check_dt_compatible_value("sun50i-h5"):
             return chips.H5
 
-        if self.detector.check_dt_compatible_value("sun50i-h6"):
-            return chips.H6
+        if self.detector.check_dt_compatible_value("sun50i-h616"):
+            return chips.H616
 
         if self.detector.check_dt_compatible_value("sun50iw9"):
             return chips.H616
 
-        if self.detector.check_dt_compatible_value("sun50i-h616"):
-            return chips.H616
+        if self.detector.check_dt_compatible_value("sun50i-h6"):
+            return chips.H6
 
         if self.detector.check_dt_compatible_value("mediatek,mt8167"):
             return chips.MT8167
@@ -228,6 +263,15 @@ class Chip:
         if self.detector.check_dt_compatible_value("imx6ull"):
             return chips.IMX6ULL
 
+        if self.detector.check_dt_compatible_value("ti,j721e"):
+            return chips.TDA4VM
+
+        if self.detector.check_dt_compatible_value("sun20i-d1"):
+            return chips.D1_RISCV
+
+        if self.detector.check_dt_compatible_value("libretech,aml-s905x-cc"):
+            return chips.S905X
+
         linux_id = None
         hardware = self.detector.get_cpuinfo_field("Hardware")
 
@@ -249,6 +293,8 @@ class Chip:
                     linux_id = chips.PENTIUM_N3710
                 elif "X5-Z8350" in model_name:
                     linux_id = chips.ATOM_X5_Z8350
+                elif "J4105" in model_name:
+                    linux_id = chips.ATOM_J4105
                 else:
                     linux_id = chips.GENERIC_X86
             ##            print("linux_id = ", linux_id)
@@ -262,6 +308,8 @@ class Chip:
                     linux_id = chips.T186
                 elif "nvidia,tegra194" in compats:
                     linux_id = chips.T194
+                elif "nvidia,tegra234" in compats:
+                    linux_id = chips.T234
             if compatible and "imx8m" in compatible:
                 linux_id = chips.IMX8MX
             if compatible and "odroid-c2" in compatible:
@@ -277,6 +325,8 @@ class Chip:
                     return chips.S922X
                 if "sm1" in compatible_list:
                     return chips.S905X3
+                if "vim3amlogic" in compatible_list:
+                    return chips.A311D
             if compatible and "sun50i-a64" in compatible:
                 linux_id = chips.A64
             if compatible and "sun50i-h6" in compatible:
@@ -285,7 +335,6 @@ class Chip:
                 linux_id = chips.H5
             if compatible and "odroid-xu4" in compatible:
                 linux_id = chips.EXYNOS5422
-
             cpu_model = self.detector.get_cpuinfo_field("cpu model")
 
             if cpu_model is not None:
@@ -307,6 +356,10 @@ class Chip:
                 linux_id = chips.AM33XX
             elif "DRA74X" in hardware:
                 linux_id = chips.DRA74X
+            elif "sun4i" in hardware:
+                linux_id = chips.A10
+            elif "sun7i" in hardware:
+                linux_id = chips.A20
             elif "sun8i" in hardware:
                 linux_id = chips.SUN8I
             elif "ODROIDC" in hardware:
@@ -319,6 +372,8 @@ class Chip:
                 linux_id = chips.S905X3
             elif "ODROID-XU4" in hardware:
                 linux_id = chips.EXYNOS5422
+            elif "KHADAS-VIM3" in hardware:
+                linux_id = chips.A311D
             elif "SAMA5" in hardware:
                 linux_id = chips.SAMA5
             elif "Pinebook" in hardware:
@@ -339,7 +394,7 @@ class Chip:
 
         return linux_id
 
-    def __getattr__(self, attr):
+    def __getattr__(self, attr: str) -> bool:
         """
         Detect whether the given attribute is the currently-detected chip.  See
         list of constants at the top of this module for available options.
